##*************************************************************************##
##  CUBE        http://www.scalasca.org/                                   ##
##*************************************************************************##
##  Copyright (c) 2023                                                     ##
##  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          ##
##                                                                         ##
##  This software may be modified and distributed under the terms of       ##
##  a BSD-style license.  See the COPYING file in the package base         ##
##  directory for details.                                                 ##
##*************************************************************************##


TEMPLATE = subdirs

# ============================================================================================
# set environmen variable CUBELIB_ROOT if the path to CubeLib installation is not /opt/cubelib
# ============================================================================================

CUBELIB_ROOT = $$(CUBELIB_ROOT) # where cubelib has been installed
CUBEGUI_ROOT = $$(CUBEGUI_ROOT) # where cubegui should be installed

isEmpty( CUBELIB_ROOT ) {
    CUBELIB_ROOT = /opt/cubelib
    warning("Warning: The environment variable CUBELIB_ROOT is not set. Using $$CUBELIB_ROOT as default.")
}
isEmpty( CUBEGUI_ROOT ) {
    CUBEGUI_ROOT = /opt/cubegui-pro
    warning("Warning: The environment variable CUBEGUI_ROOT is not set. Using $$CUBEGUI_ROOT as default.")
}
message( "CUBEGUI_ROOT=\"$$CUBEGUI_ROOT\", CUBELIB_ROOT=\"$$CUBELIB_ROOT\"")

# =============================================================================
# create header files with version and system information
# =============================================================================

createHeader.target = include/config.h
linux {
    ENV = "PKGDATADIR=$$CUBEGUI_ROOT/share/cubegui"
    createHeader.commands = $$system($$ENV include/cubegui-config.sh)
}
windows {
    createHeader.commands = $$system(bash include/cubegui-config.sh)
}

QMAKE_EXTRA_TARGETS += createHeader
PRE_TARGETDEPS += include/config.h

# =============================================================================
# subdirs and dependencies
# =============================================================================

SUBDIRS = \
        cubegui-core \
        cubegui \
        plugin-advanced-colormap \
        plugin-advisor \
        plugin-barplot \
        plugin-diff \
        plugin-graphwidgetcommon \
        plugin-heatmap \
        plugin-launch \
        plugin-mean \
        plugin-merge \
        plugin-metriceditor \
        plugin-metricident \
        plugin-scaling \
        plugin-scorepconfig \
        plugin-sourcecodeviewer \
        plugin-statistics \
        plugin-sunburst \
        plugin-systemboxplot \
        plugin-systemtopology \
        plugin-tau2cube \
        plugin-treeitemmarker

# =============================================================================
# dependencies ( build cubegui-core first, then cubegui and then the plugins )
# =============================================================================
        cubegui.depends = cubegui-core
        plugin-advanced-colormap.depends = cubegui
        plugin-advisor.depends = cubegui
        plugin-barplot.depends = cubegui plugin-graphwidgetcommon
        plugin-diff.depends = cubegui
        plugin-graphwidgetcommon.depends = cubegui
        plugin-heatmap.depends = cubegui plugin-graphwidgetcommon
        plugin-launch.depends = cubegui
        plugin-mean.depends = cubegui
        plugin-merge.depends = cubegui
        plugin-metriceditor.depends = cubegui
        plugin-metricident.depends = cubegui
        plugin-scaling.depends = cubegui
        plugin-scorepconfig.depends = cubegui
        plugin-sourcecodeviewer.depends = cubegui
        plugin-statistics.depends = cubegui
        plugin-sunburst.depends = cubegui
        plugin-systemboxplot.depends = cubegui
        plugin-systemtopology.depends = cubegui
        plugin-tau2cube.depends = cubegui
        plugin-treeitemmarker.depends = cubegui

# =============================================================================
# install
# =============================================================================

CONFIG(debug, debug|release) {
    DESTDIR =  $$PWD/build-debug
}
CONFIG(release, debug|release) {
    DESTDIR = $$PWD/build-release
}

examples.path = $${CUBEGUI_ROOT}/share/doc/cubegui/example/
examples.files = ../examples/GUI/*.cubex ../examples/GUI/plugins # todo: replace cubegui-config

bin.path   = $${CUBEGUI_ROOT}/bin/
bin.files  = $${DESTDIR}/bin/*
bin.CONFIG = no_check_exist

lib.path   = $${CUBEGUI_ROOT}/lib
lib.files  = $${DESTDIR}/lib/*
lib.CONFIG = no_check_exist

doc.path  = $${CUBEGUI_ROOT}/share/doc/cubegui/
doc.extra = cd ../doc && tar -zxf guide-html.tar.gz && tar -zxf plugins-guide-html.tar.gz
doc.files = ../doc/guide ../doc/plugins-guide ../doc/*.pdf ../OPEN_ISSUES ../README
doc.CONFIG = no_check_exist

icons.path  = $${CUBEGUI_ROOT}/share/icons
icons.files = ../share/icons/*

SOURCES="../src/GUI-qt/display"
includes.path = $${CUBEGUI_ROOT}/include/cubegui
includes.files = $$SOURCES/AggregatedTreeItem.h \
                 $$SOURCES/ColorMap.h \
                 $$SOURCES/Constants.h \
                 $$SOURCES/Future.h \
                 $$SOURCES/Globals.h \
                 $$SOURCES/SettingsHandler.h \
                 $$SOURCES/TabInterface.h \
                 $$SOURCES/Task.h \
                 $$SOURCES/TreeItem.h \
                 $$SOURCES/TreeItemMarker.h \
                 $$SOURCES/plugins/ContextFreePlugin.h \
                 $$SOURCES/plugins/ContextFreeServices.h \
                 $$SOURCES/plugins/CubePlugin.h \
                 $$SOURCES/plugins/PluginInterface.h \
                 $$SOURCES/plugins/PluginServiceExports.h \
                 $$SOURCES/plugins/PluginServices.h \
                 $$SOURCES/plugins/ValueView.h \
                 $$SOURCES/utils/StatisticalInformation.h \
                 include/cubegui-concurrent.h \
                 include/cubegui-version.h \
                 include/cubegui-config.h
includes.config = no_check_exist

INSTALLS += bin doc lib examples icons includes
