::*************************************************************************::
::  CUBE        http://www.scalasca.org/                                   ::
::*************************************************************************::
::  Copyright (c) 2023                                                     ::
::  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          ::
::                                                                         ::
::  This software may be modified and distributed under the terms of       ::
::  a BSD-style license.  See the COPYING file in the package base         ::
::  directory for details.                                                 ::
::*************************************************************************::


:: maintainer Pavel Saviankou <p.saviankou@fz-juelich.de>

:: required environment variables:
:: TARGET: location where CubeGui will be installed
:: QTDIR:  location of QT installation, required to distribute libraries
:: MINGW:  location of minwg installation, required to distribute libraries

:: =========  build cubegui using default project files
echo "build cubegui..."

set CUBELIB_ROOT=%TARGET%
set CUBEGUI_ROOT=%TARGET%

cd ../../qmake
qmake
mingw32-make || goto :error

:: workaround for windows: 2nd run of qmake required after libs have been created; CONFIG = no_check_exist doesn't work on windows
echo "install cubegui to %TARGET%..."
qmake
mingw32-make install || goto :error

:: =========  prepare distribution
mkdir %TARGET%\include\cubew
mkdir %TARGET%\include\cubelib

:: ========= copy cube libraries and plugins into library search path (bin)
copy "%TARGET%\lib\*.dll" %TARGET%\bin
copy "%TARGET%\lib\cube-plugins\*.dll" %TARGET%\bin

echo "Copy system libraries..."
copy %MINGW%\bin\libgcc_s_*.dll %TARGET%\bin || goto :error
copy %MINGW%\bin\libstdc*-6.dll %TARGET%\bin || goto :error
copy %MINGW%\bin\libwinpthread*.dll %TARGET%\bin || goto :error
echo "Copy Qt libraries..."
echo "Qt located  : %QTDIR%"
copy %QTDIR%\bin\Qt5Core.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Concurrent.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Gui.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Network.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5PrintSupport.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Help.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Web*.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Widgets.dll %TARGET%\bin || goto :error

echo "Create directories for plugins..."
mkdir %TARGET%\bin\platforms
mkdir %TARGET%\bin\bearer
mkdir %TARGET%\bin\styles
mkdir %TARGET%\bin\imageformats

echo "Copy Qt platforms..."

copy %QTDIR%\plugins\platforms\qwindows.dll %TARGET%\bin\platforms || goto :error
copy %QTDIR%\plugins\bearer\qgenericbearer.dll %TARGET%\bin\bearer || goto :error
copy %QTDIR%\plugins\styles\qwindowsvistastyle.dll %TARGET%\bin\styles || goto :error
copy %QTDIR%\plugins\imageformats\qgif.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qicns.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qico.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qjpeg.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qsvg.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qtga.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qtiff.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qwbmp.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qwebp.dll %TARGET%\bin\imageformats || goto :error

@echo "Copy Cube license..."
copy  ..\COPYING %TARGET%\cubelicense.txt || goto :error

copy  windows\cubeinstaller.nsi %TARGET%\.. || goto :error
::echo "NOW COMPILE NSIS installer script..."

:: =========  end prepare distribution

exit /b 0

:error
if errorlevel 1 (
   echo "Failure during copy : %errorlevel%"
   exit /b %errorlevel%
)
